searchNodes=[{"doc":"Fxnk is a functional programming library for Elixir inspired by Ramda.It includes functions for flow, lists, logic, maps, and math. Typically, you'd just want to import what you need, such as import Fxnk.Flow, only: [if_else: 4].And then you would use it like this:defmodule Something.Cool do import Fxnk.Flow, only: [if_else: 4] def do_stuff(a, b, c) do a |&gt; foo(b) |&gt; bar(c) |&gt; if_else(is_awesome?, do_awesome_stuff/1, make_awesome/1) end endFxnk's functions are also curried for easy reading.Examplesiex&gt; import Fxnk.Flow iex&gt; import Fxnk.Logic iex&gt; import Fxnk.Math iex&gt; isGreaterThan5? = gt?(5) iex&gt; isLessThan10? = lt?(10) iex&gt; isGreaterThan5AndLessThan10? = both?(isGreaterThan5?, isLessThan10?) iex&gt; isGreaterThan5AndLessThan10?.(8) true iex&gt; timesTwo = multiply(2) iex&gt; multiplyByTwoIfBetween5and10 = when_is(isGreaterThan5AndLessThan10?, timesTwo) iex&gt; multiplyByTwoIfBetween5and10.(8) 16You also don't need to predefine the functions to use them.Examplesiex&gt; import Fxnk.Flow iex&gt; import Fxnk.Logic iex&gt; import Fxnk.Math iex&gt; multiplyByTwoIfBetween5and10 = when_is(both?(gt?(5), lt?(10)), multiply(2)) iex&gt; multiplyByTwoIfBetween5and10.(8) 16","ref":"Fxnk.html","title":"Fxnk","type":"module"},{"doc":"Fxnk.Flow functions are used for control flow.","ref":"Fxnk.Flow.html","title":"Fxnk.Flow","type":"module"},{"doc":"Curried compose/2.Examplesiex&gt; reverseSort = Fxnk.Flow.compose([&amp;Enum.reverse/1, &amp;Enum.sort/1]) iex&gt; reverseSort.([1,3,5,7,6,4,2]) [7, 6, 5, 4, 3, 2, 1]","ref":"Fxnk.Flow.html#compose/1","title":"Fxnk.Flow.compose/1","type":"function"},{"doc":"compose/2 takes an input and a list of functions and runs the functions against the input from right to left.Examplesiex&gt; [1,3,5,7,6,4,2] |&gt; Fxnk.Flow.compose([&amp;Enum.reverse/1, &amp;Enum.sort/1]) [7, 6, 5, 4, 3, 2, 1]","ref":"Fxnk.Flow.html#compose/2","title":"Fxnk.Flow.compose/2","type":"function"},{"doc":"Curried if_else/3Examplesiex&gt; multTwoIfLessThanTenOrDivideByTwo = Fxnk.Flow.if_else(fn x -&gt; x &lt; 10 end, fn x -&gt; x * 2 end, fn x -&gt; div(x, 2) end) iex&gt; multTwoIfLessThanTenOrDivideByTwo.(5) 10 iex&gt; multTwoIfLessThanTenOrDivideByTwo.(20) 10","ref":"Fxnk.Flow.html#if_else/3","title":"Fxnk.Flow.if_else/3","type":"function"},{"doc":"if_else/4 takes an input, a predicate, a pass function and a fail function. Runs the pass function if the predicate returns true when passed the input, otherwise runs the fail function.Examplesiex&gt; Fxnk.Flow.if_else(5, fn x -&gt; x &lt; 10 end, fn x -&gt; x * 2 end, fn x -&gt; div(x, 2) end) 10 iex&gt; Fxnk.Flow.if_else(20, fn x -&gt; x &lt; 10 end, fn x -&gt; x * 2 end, fn x -&gt; div(x, 2) end) 10","ref":"Fxnk.Flow.html#if_else/4","title":"Fxnk.Flow.if_else/4","type":"function"},{"doc":"Curried pipe/2.Examplesiex&gt; reverseSort = Fxnk.Flow.pipe([&amp;Enum.sort/1, &amp;Enum.reverse/1]) iex&gt; reverseSort.([1,3,5,7,6,4,2]) [7, 6, 5, 4, 3, 2, 1]","ref":"Fxnk.Flow.html#pipe/1","title":"Fxnk.Flow.pipe/1","type":"function"},{"doc":"pipe/2 takes an input and a list of functions and runs the functions against the input from left to right.Examplesiex&gt; [1,3,5,7,6,4,2] |&gt; Fxnk.Flow.pipe([&amp;Enum.sort/1, &amp;Enum.reverse/1]) [7, 6, 5, 4, 3, 2, 1]","ref":"Fxnk.Flow.html#pipe/2","title":"Fxnk.Flow.pipe/2","type":"function"},{"doc":"Curried unless_is/3.Examplesiex&gt; multiplyByTwoUnlessGreaterThan10 = Fxnk.Flow.unless_is(fn n -&gt; n &gt; 10 end, fn x -&gt; x * 2 end) iex&gt; multiplyByTwoUnlessGreaterThan10.(15) 15 iex&gt; multiplyByTwoUnlessGreaterThan10.(2) 4","ref":"Fxnk.Flow.html#unless_is/2","title":"Fxnk.Flow.unless_is/2","type":"function"},{"doc":"unless_is is a logic flow function, which takes an input, a predicate function, and an action function, allowing the action function to run unless the input returns true when ran against the predicate.Exampleiex&gt; Fxnk.Flow.unless_is(15, fn n -&gt; n &gt; 10 end, fn x -&gt; x * 2 end) 15 iex&gt; Fxnk.Flow.unless_is(2, fn n -&gt; n &gt; 10 end, fn x -&gt; x * 2 end) 4","ref":"Fxnk.Flow.html#unless_is/3","title":"Fxnk.Flow.unless_is/3","type":"function"},{"doc":"Curried until/3.Examplesiex&gt; timesTwoUntilGreaterThan100 = Fxnk.Flow.until(fn x -&gt; x &gt; 100 end, fn n -&gt; n * 2 end) iex&gt; timesTwoUntilGreaterThan100.(1) 128","ref":"Fxnk.Flow.html#until/2","title":"Fxnk.Flow.until/2","type":"function"},{"doc":"until/3 takes an input, a predicate function and an action function, running the action function on the input until the predicate is satisfied.Examplesiex&gt; Fxnk.Flow.until(1, fn x -&gt; x &gt; 100 end, fn n -&gt; n * 2 end) 128","ref":"Fxnk.Flow.html#until/3","title":"Fxnk.Flow.until/3","type":"function"},{"doc":"Curried when_is/3.Examplesiex&gt; timesTwoWhenGreaterThan10 = Fxnk.Flow.when_is(fn x -&gt; x &gt; 10 end, fn n -&gt; n * 2 end) iex&gt; timesTwoWhenGreaterThan10.(15) 30 iex&gt; timesTwoWhenGreaterThan10.(5) 5","ref":"Fxnk.Flow.html#when_is/2","title":"Fxnk.Flow.when_is/2","type":"function"},{"doc":"when_is is a logic flow function, which takes an input, a predicate function, and an action function, allowing the action function to run when the input returns true when ran against the predicate.Examplesiex&gt; Fxnk.Flow.when_is(15, fn x -&gt; x &gt; 10 end, fn n -&gt; n * 2 end) 30 iex&gt; Fxnk.Flow.when_is(5, fn x -&gt; x &gt; 10 end, fn n -&gt; n * 2 end) 5","ref":"Fxnk.Flow.html#when_is/3","title":"Fxnk.Flow.when_is/3","type":"function"},{"doc":"Fxnk.Functions are functions for computation or helpers.","ref":"Fxnk.Functions.html","title":"Fxnk.Functions","type":"module"},{"doc":"always/1 returns the value passed to it always.Examplesiex&gt; fourtyTwo = Fxnk.Functions.always(42) iex&gt; fourtyTwo.(&quot;hello&quot;) 42","ref":"Fxnk.Functions.html#always/1","title":"Fxnk.Functions.always/1","type":"function"},{"doc":"always/2 returns the second value passed to it always.Examplesiex&gt; Fxnk.Functions.always(&quot;hello&quot;, 42) 42","ref":"Fxnk.Functions.html#always/2","title":"Fxnk.Functions.always/2","type":"function"},{"doc":"Curried converge/3Example iex&gt; reverseUpcaseConcat = Fxnk.Functions.converge(&amp;Fxnk.String.concat/2, [&amp;String.reverse/1, &amp;String.upcase/1]) iex&gt; reverseUpcaseConcat.(&quot;hello&quot;) &quot;ollehHELLO&quot;","ref":"Fxnk.Functions.html#converge/2","title":"Fxnk.Functions.converge/2","type":"function"},{"doc":"converge/3 takes an initial argument, a function and a list of functions. It applies the argument to each of the list of functions and then applies the results of those functions as the argument to the end function.The end function must have the same arity as the length of the list of functions.Exampleiex&gt; Fxnk.Functions.converge(&quot;hello&quot;, &amp;Fxnk.String.concat/2, [&amp;String.reverse/1, &amp;String.upcase/1]) &quot;ollehHELLO&quot;","ref":"Fxnk.Functions.html#converge/3","title":"Fxnk.Functions.converge/3","type":"function"},{"doc":"curry/1 takes a function and returns a function.Examplesiex&gt; add = Fxnk.Functions.curry(fn (a, b) -&gt; a + b end) iex&gt; add.(6).(7) 13 iex&gt; addOne = Fxnk.Functions.curry(add.(1)) iex&gt; addOne.(1336) 1337","ref":"Fxnk.Functions.html#curry/1","title":"Fxnk.Functions.curry/1","type":"function"},{"doc":"A function that always returns false.","ref":"Fxnk.Functions.html#falsy/0","title":"Fxnk.Functions.falsy/0","type":"function"},{"doc":"Takes a function, returns a function that takes the same args as the initial function, but flips the order of the arguments.Exampleiex&gt; flippedConcatString = Fxnk.Functions.flip(&amp;Fxnk.String.concat/2) iex&gt; Fxnk.String.concat(&quot;hello&quot;, &quot;world&quot;) &quot;helloworld&quot; iex&gt; flippedConcatString.(&quot;hello&quot;, &quot;world&quot;) &quot;worldhello&quot;","ref":"Fxnk.Functions.html#flip/1","title":"Fxnk.Functions.flip/1","type":"function"},{"doc":"Same as flip/1, but takes the arguments at the same time as the function.Exampleiex&gt; Fxnk.Functions.flip(&quot;hello&quot;, &quot;world&quot;, &amp;Fxnk.String.concat/2) &quot;worldhello&quot;","ref":"Fxnk.Functions.html#flip/3","title":"Fxnk.Functions.flip/3","type":"function"},{"doc":"identity/1 returns what was passed to it.Exampleiex&gt; Fxnk.Functions.identity(42) 42","ref":"Fxnk.Functions.html#identity/1","title":"Fxnk.Functions.identity/1","type":"function"},{"doc":"juxt/1 takes list of functions and returns a curried juxt.Exampleiex&gt; minmax = Fxnk.Functions.juxt([&amp;Fxnk.Math.min/1, &amp;Fxnk.Math.max/1]) iex&gt; minmax.([1,3,5,7]) [1, 7]","ref":"Fxnk.Functions.html#juxt/1","title":"Fxnk.Functions.juxt/1","type":"function"},{"doc":"juxt/2 takes an initial argument and list of functions and applies the functions to the argument.Exampleiex&gt; Fxnk.Functions.juxt(%{foo: &quot;foo&quot;, bar: &quot;bar&quot;, baz: &quot;baz&quot;}, [Fxnk.Map.prop(:foo), Fxnk.Map.prop(:bar)]) [&quot;foo&quot;, &quot;bar&quot;]","ref":"Fxnk.Functions.html#juxt/2","title":"Fxnk.Functions.juxt/2","type":"function"},{"doc":"tap/1 takes a function and returns a function that takes a value. Applies the value to the function and then returns the value.Exampleiex&gt; function = Fxnk.Functions.tap(&amp;Fxnk.Math.inc/1) iex&gt; function.(42) 42","ref":"Fxnk.Functions.html#tap/1","title":"Fxnk.Functions.tap/1","type":"function"},{"doc":"tap/2 takes a value and a function, applies the value to the function and returns the value.Exampleiex&gt; Fxnk.Functions.tap(42, &amp;Fxnk.Math.inc/1) 42","ref":"Fxnk.Functions.html#tap/2","title":"Fxnk.Functions.tap/2","type":"function"},{"doc":"Function that always returns true.Exampleiex&gt; Fxnk.Functions.truthy() true","ref":"Fxnk.Functions.html#truthy/0","title":"Fxnk.Functions.truthy/0","type":"function"},{"doc":"Fxnk.List are functions for working with lists.","ref":"Fxnk.List.html","title":"Fxnk.List","type":"module"},{"doc":"reduce_right/3 takes a list of args, an initial value and a function and returns a single value.Like reduce, it applies the function to each of the arguments, and accumulating the result, except it does it right to left.Examplesiex&gt; Fxnk.List.reduce_right([1,2,3,4,5], 0, fn a, b -&gt; a + b end) 15","ref":"Fxnk.List.html#reduce_right/3","title":"Fxnk.List.reduce_right/3","type":"function"},{"doc":"zip_map/2 is a lot like Enum.zip/2, but instead of returning a list of tuples, it returns a list of maps, where the keys are the second list passed in.Examplesiex&gt; Fxnk.List.zip_map([&quot;hello&quot;, &quot;world&quot;], [&quot;first&quot;, &quot;second&quot;]) [%{&quot;first&quot; =&gt; &quot;hello&quot;}, %{&quot;second&quot; =&gt; &quot;world&quot;}]","ref":"Fxnk.List.html#zip_map/2","title":"Fxnk.List.zip_map/2","type":"function"},{"doc":"Fxnk.Logic are functions for dealing with booleans.","ref":"Fxnk.Logic.html","title":"Fxnk.Logic","type":"module"},{"doc":"Curried and?/2.Examplesiex&gt; isTwo? = Fxnk.Logic.and?(2) iex&gt; isTwo?.(2) true iex&gt; isTwo?.(3) false","ref":"Fxnk.Logic.html#and?/1","title":"Fxnk.Logic.and?/1","type":"function"},{"doc":"and? returns true if both inputs are the same, opposite of is_not/2.Examplesiex&gt; Fxnk.Logic.and?(2, 2) true iex&gt; Fxnk.Logic.and?(&quot;hello&quot;, &quot;world&quot;) false","ref":"Fxnk.Logic.html#and?/2","title":"Fxnk.Logic.and?/2","type":"function"},{"doc":"Curried both?/3.Examplesiex&gt; gt10lt20? = Fxnk.Logic.both?(fn x -&gt; x &gt; 10 end, fn x -&gt; x &lt; 20 end) iex&gt; gt10lt20?.(15) true iex&gt; gt10lt20?.(30) false","ref":"Fxnk.Logic.html#both?/2","title":"Fxnk.Logic.both?/2","type":"function"},{"doc":"both?/3 takes an input and two predicate functions, returning true if both functions are true when passed the input.Examplesiex&gt; Fxnk.Logic.both?(15, fn x -&gt; x &gt; 10 end, fn x -&gt; x &lt; 20 end) true iex&gt; Fxnk.Logic.both?(30, fn x -&gt; x &gt; 10 end, fn x -&gt; x &lt; 20 end) false","ref":"Fxnk.Logic.html#both?/3","title":"Fxnk.Logic.both?/3","type":"function"},{"doc":"complement/1 returns the opposite of the boolean passed to it.Examplesiex&gt; Fxnk.Logic.complement(true) false iex&gt; Fxnk.Logic.complement(false) true","ref":"Fxnk.Logic.html#complement/1","title":"Fxnk.Logic.complement/1","type":"function"},{"doc":"Curried default_to/2Examplesiex&gt; defaultTo42 = Fxnk.Logic.default_to(42) iex&gt; defaultTo42.(false) 42 iex&gt; defaultTo42.(nil) 42 iex&gt; defaultTo42.(&quot;thanks for all the fish&quot;) &quot;thanks for all the fish&quot;","ref":"Fxnk.Logic.html#default_to/1","title":"Fxnk.Logic.default_to/1","type":"function"},{"doc":"default_to/2 takes two values and returns the right side value if the left side is false or nilExamplesiex&gt; false |&gt; Fxnk.Logic.default_to(42) 42 iex&gt; nil |&gt; Fxnk.Logic.default_to(42) 42 iex&gt; &quot;hello, world&quot; |&gt; Fxnk.Logic.default_to(42) &quot;hello, world&quot;","ref":"Fxnk.Logic.html#default_to/2","title":"Fxnk.Logic.default_to/2","type":"function"},{"doc":"Curried either/3Examplesiex&gt; lt10orGt30? = Fxnk.Logic.either?(fn x -&gt; x &lt; 10 end, fn x -&gt; x &gt; 30 end) iex&gt; lt10orGt30?.(5) true iex&gt; lt10orGt30?.(15) false","ref":"Fxnk.Logic.html#either?/2","title":"Fxnk.Logic.either?/2","type":"function"},{"doc":"either?/3 takes an input and two predicate functions and returns true if either predicate is true.Examplesiex&gt; Fxnk.Logic.either?(5, fn x -&gt; x &lt; 10 end, fn x -&gt; x &gt; 30 end) true iex&gt; Fxnk.Logic.either?(15, fn x -&gt; x &lt; 10 end, fn x -&gt; x &gt; 30 end) false","ref":"Fxnk.Logic.html#either?/3","title":"Fxnk.Logic.either?/3","type":"function"},{"doc":"Curried greater than function, returns a function that returns true if the second number passed in is greater than the first.Examples iex&gt; greaterThan5? = Fxnk.Logic.gt?(5) iex&gt; greaterThan5?.(19) true iex&gt; greaterThan5?.(3) false","ref":"Fxnk.Logic.html#gt?/1","title":"Fxnk.Logic.gt?/1","type":"function"},{"doc":"is_empty/1 returns true if passed an empty Map or List.Examplesiex&gt; Fxnk.Logic.is_empty([]) true iex&gt; Fxnk.Logic.is_empty(%{}) true iex&gt; Fxnk.Logic.is_empty([1,1,2,3,5,8]) false","ref":"Fxnk.Logic.html#is_empty/1","title":"Fxnk.Logic.is_empty/1","type":"function"},{"doc":"Curried is_not?/2Examplesiex&gt; isNotThree = Fxnk.Logic.is_not?(3) iex&gt; isNotThree.(3) false iex&gt; isNotThree.(4) true","ref":"Fxnk.Logic.html#is_not?/1","title":"Fxnk.Logic.is_not?/1","type":"function"},{"doc":"is_not/3 returns true if both inputs are not the same, opposite of and?/2Examplesiex&gt; Fxnk.Logic.is_not?(3, 3) false iex&gt; Fxnk.Logic.is_not?(3, 4) true","ref":"Fxnk.Logic.html#is_not?/2","title":"Fxnk.Logic.is_not?/2","type":"function"},{"doc":"Curried less than function, returns a function that returns true if the second number passed in is less than the first.Examples iex&gt; lessThan5? = Fxnk.Logic.lt?(5) iex&gt; lessThan5?.(19) false iex&gt; lessThan5?.(3) true","ref":"Fxnk.Logic.html#lt?/1","title":"Fxnk.Logic.lt?/1","type":"function"},{"doc":"Checks if a value is equal to nil.Examplesiex&gt; Fxnk.Logic.nil?(nil) true iex&gt; Fxnk.Logic.nil?(&quot;not nil&quot;) false","ref":"Fxnk.Logic.html#nil?/1","title":"Fxnk.Logic.nil?/1","type":"function"},{"doc":"## Examplesiex&gt; Fxnk.Logic.not_nil?(nil) false iex&gt; Fxnk.Logic.not_nil?(&quot;not nil&quot;) true","ref":"Fxnk.Logic.html#not_nil?/1","title":"Fxnk.Logic.not_nil?/1","type":"function"},{"doc":"Curried or/2Examples iex&gt; willBeTrue = Fxnk.Logic.or?(true) iex&gt; willBeTrue.(false) true","ref":"Fxnk.Logic.html#or?/1","title":"Fxnk.Logic.or?/1","type":"function"},{"doc":"or/2 returns true if one or both of its arguments are true.Examplesiex&gt; Fxnk.Logic.or?(true, false) true iex&gt; Fxnk.Logic.or?(true, true) true iex&gt; Fxnk.Logic.or?(false, false) false","ref":"Fxnk.Logic.html#or?/2","title":"Fxnk.Logic.or?/2","type":"function"},{"doc":"Fxnk.Map are functions that work with maps.","ref":"Fxnk.Map.html","title":"Fxnk.Map","type":"module"},{"doc":"pick/1Accepts a list of args, returns a curried pick/2.Examplesiex&gt; pickArgs = Fxnk.Map.pick([:red, :blue, :orange]) iex&gt; pickArgs.(%{ red: &quot;RED&quot;, green: &quot;GREEN&quot;, blue: &quot;BLUE&quot;, yellow: &quot;YELLOW&quot; }) %{red: &quot;RED&quot;, blue: &quot;BLUE&quot;}","ref":"Fxnk.Map.html#pick/1","title":"Fxnk.Map.pick/1","type":"function"},{"doc":"pick/2 takes a Map and a List of atoms, and returns a map of only the selected keys that exist. It will return an empty map if passed an empty map or an empty list.Examplesiex&gt; Fxnk.Map.pick(%{ red: &quot;RED&quot;, green: &quot;GREEN&quot;, blue: &quot;BLUE&quot;, yellow: &quot;YELLOW&quot; }, [:red, :blue, :orange]) %{red: &quot;RED&quot;, blue: &quot;BLUE&quot;}","ref":"Fxnk.Map.html#pick/2","title":"Fxnk.Map.pick/2","type":"function"},{"doc":"prop/1Accepts a string key and returns a function that takes a map. Returns the map's value at key or nil.Examplesiex&gt; getProp = Fxnk.Map.prop(&quot;foo&quot;) iex&gt; getProp.(%{&quot;foo&quot; =&gt; &quot;foo&quot;, &quot;bar&quot; =&gt; &quot;bar&quot;}) &quot;foo&quot; iex&gt; getProp2 = Fxnk.Map.prop(:foo) iex&gt; getProp2.(%{foo: &quot;foo&quot;, bar: &quot;bar&quot;}) &quot;foo&quot;","ref":"Fxnk.Map.html#prop/1","title":"Fxnk.Map.prop/1","type":"function"},{"doc":"prop/2Accepts a map and a key. Returns the map's value at key or nilExamplesiex&gt; Fxnk.Map.prop(%{&quot;foo&quot; =&gt; &quot;foo&quot;, &quot;bar&quot; =&gt; &quot;bar&quot;}, &quot;foo&quot;) &quot;foo&quot; iex&gt; Fxnk.Map.prop(%{foo: &quot;foo&quot;, bar: &quot;bar&quot;}, :foo) &quot;foo&quot;","ref":"Fxnk.Map.html#prop/2","title":"Fxnk.Map.prop/2","type":"function"},{"doc":"props/1Accepts a list of keys and returns a function that takes a map. Returns a list of the values associated with the keys in the map.Examplesiex&gt; getProps = Fxnk.Map.props([&quot;foo&quot;, &quot;bar&quot;]) iex&gt; getProps.(%{&quot;foo&quot; =&gt; &quot;foo&quot;, &quot;bar&quot; =&gt; &quot;bar&quot;, &quot;baz&quot; =&gt; &quot;baz&quot;}) [&quot;foo&quot;, &quot;bar&quot;] iex&gt; getProps2 = Fxnk.Map.props([:foo, :bar]) iex&gt; getProps2.(%{foo: &quot;foo&quot;, bar: &quot;bar&quot;, baz: &quot;baz&quot;}) [&quot;foo&quot;, &quot;bar&quot;]","ref":"Fxnk.Map.html#props/1","title":"Fxnk.Map.props/1","type":"function"},{"doc":"props/2Accepts a map and a list of keys and returns a list of the values associated with the keys in the map.Examplesiex&gt; Fxnk.Map.props(%{&quot;foo&quot; =&gt; &quot;foo&quot;, &quot;bar&quot; =&gt; &quot;bar&quot;, &quot;baz&quot; =&gt; &quot;baz&quot;}, [&quot;foo&quot;, &quot;bar&quot;]) [&quot;foo&quot;, &quot;bar&quot;] iex&gt; Fxnk.Map.props(%{foo: &quot;foo&quot;, bar: &quot;bar&quot;, baz: &quot;baz&quot;}, [:foo, :bar]) [&quot;foo&quot;, &quot;bar&quot;]","ref":"Fxnk.Map.html#props/2","title":"Fxnk.Map.props/2","type":"function"},{"doc":"Fxnk.Math are functions dealing with math.","ref":"Fxnk.Math.html","title":"Fxnk.Math","type":"module"},{"doc":"Curried Add/2Exampleiex&gt; addOne = Fxnk.Math.add(1) iex&gt; addOne.(2) 3","ref":"Fxnk.Math.html#add/1","title":"Fxnk.Math.add/1","type":"function"},{"doc":"Add two numbers togetherExampleiex&gt; Fxnk.Math.add(1, 2) 3","ref":"Fxnk.Math.html#add/2","title":"Fxnk.Math.add/2","type":"function"},{"doc":"Averages a list of numbers, returns a float.Examplesiex&gt; Fxnk.Math.avg([1,4,3,2,5]) 3.0","ref":"Fxnk.Math.html#avg/1","title":"Fxnk.Math.avg/1","type":"function"},{"doc":"Curried clamp/3. Restrict a number to be between a range of numbers.Exampleiex&gt; between1And10 = Fxnk.Math.clamp(1, 10) iex&gt; between1And10.(-5) 1 iex&gt; between1And10.(15) 10","ref":"Fxnk.Math.html#clamp/2","title":"Fxnk.Math.clamp/2","type":"function"},{"doc":"Restrict a number to be between a range of numbers.Exampleiex&gt; Fxnk.Math.clamp(13, 15, 20) 15 iex&gt; Fxnk.Math.clamp(21, 15, 20) 20 iex&gt; Fxnk.Math.clamp(17, 15, 20) 17","ref":"Fxnk.Math.html#clamp/3","title":"Fxnk.Math.clamp/3","type":"function"},{"doc":"Decrement a numberExampleiex&gt; Fxnk.Math.dec(1) 0","ref":"Fxnk.Math.html#dec/1","title":"Fxnk.Math.dec/1","type":"function"},{"doc":"Curried divideExamplesiex&gt; recip = Fxnk.Math.divide(1) iex&gt; recip.(4) 0.25","ref":"Fxnk.Math.html#divide/1","title":"Fxnk.Math.divide/1","type":"function"},{"doc":"Division.divide(a, b) == a / bExamples iex(1)&gt; Fxnk.Math.divide(1, 4) 0.25","ref":"Fxnk.Math.html#divide/2","title":"Fxnk.Math.divide/2","type":"function"},{"doc":"Increment a numberExampleiex&gt; Fxnk.Math.inc(1) 2","ref":"Fxnk.Math.html#inc/1","title":"Fxnk.Math.inc/1","type":"function"},{"doc":"Find the maximum of a list.Exampleiex&gt; Fxnk.Math.max([1337, 42, 23]) 1337","ref":"Fxnk.Math.html#max/1","title":"Fxnk.Math.max/1","type":"function"},{"doc":"Find the minimum of a listExampleiex&gt; Fxnk.Math.min([1337, 42, 23]) 23","ref":"Fxnk.Math.html#min/1","title":"Fxnk.Math.min/1","type":"function"},{"doc":"Curried multiply/2Examplesiex&gt; timesTen = Fxnk.Math.multiply(10) iex&gt; timesTen.(10) 100","ref":"Fxnk.Math.html#multiply/1","title":"Fxnk.Math.multiply/1","type":"function"},{"doc":"Multiplicationmultiply(a, b) == a * bExamplesiex&gt; Fxnk.Math.multiply(10, 10) 100","ref":"Fxnk.Math.html#multiply/2","title":"Fxnk.Math.multiply/2","type":"function"},{"doc":"Multiply a number times -1.Examples iex&gt; Fxnk.Math.negate(100) -100 iex&gt; Fxnk.Math.negate(-100) 100","ref":"Fxnk.Math.html#negate/1","title":"Fxnk.Math.negate/1","type":"function"},{"doc":"Curried subtract/2Examplesiex&gt; minusOne = Fxnk.Math.subtract(1) iex&gt; minusOne.(5) 4","ref":"Fxnk.Math.html#subtract/1","title":"Fxnk.Math.subtract/1","type":"function"},{"doc":"Subtract the second argument from the first.Examplesiex&gt; Fxnk.Math.subtract(5, 1) 4","ref":"Fxnk.Math.html#subtract/2","title":"Fxnk.Math.subtract/2","type":"function"},{"doc":"Functions for working with strings.","ref":"Fxnk.String.html","title":"Fxnk.String","type":"module"},{"doc":"Concatenate two strings.Exampleiex&gt; Fxnk.String.concat(&quot;hello&quot;, &quot;world&quot;) &quot;helloworld&quot;","ref":"Fxnk.String.html#concat/2","title":"Fxnk.String.concat/2","type":"function"},{"doc":"fxnkFxnk is a functional programming library for Elixir inspired by Ramda.It includes functions for flow, lists, logic, maps, and math. Typically, you'd just want to import what you need, such as import Fxnk.Flow, only: [if_else: 4].And then you would use it like this:defmodule Something.Cool do import Fxnk.Flow, only: [if_else: 4] def do_stuff(a, b, c) do a |&gt; foo(b) |&gt; bar(c) |&gt; if_else(is_awesome?, do_awesome_stuff/1, make_awesome/1) end endFxnk's functions are also curried for easy reading. iex&gt; import Fxnk.Flow iex&gt; import Fxnk.Logic iex&gt; import Fxnk.Math iex&gt; isGreaterThan5? = gt?(5) iex&gt; isLessThan10? = lt?(10) iex&gt; isGreaterThan5AndLessThan10? = both?(isGreaterThan5?, isLessThan10?) iex&gt; isGreaterThan5AndLessThan10?.(8) true iex&gt; timesTwo = multiply(2) iex&gt; multiplyByTwoIfBetween5and10 = when_is(isGreaterThan5AndLessThan10?, timesTwo) iex&gt; multiplyByTwoIfBetween5and10.(8) 16You also don't need to predefine the functions to use them. iex&gt; import Fxnk.Flow iex&gt; import Fxnk.Logic iex&gt; import Fxnk.Math iex&gt; multiplyByTwoIfBetween5and10 = when_is(both?(gt?(5), lt?(10)), multiply(2)) iex&gt; multiplyByTwoIfBetween5and10.(8) 16","ref":"readme.html","title":"fxnk","type":"extras"}]